==> react-native-web-material-0.4.2.tgz: package/src/Elevation/Elevation.styles.js <==
// $FlowFixMe
import { Platform, StyleSheet } from 'react-native';

const umbraColor = 'rgba(0, 0, 0, 0.2)';
const penumbraColor = 'rgba(0, 0, 0, 0.14)';
const ambientColor = 'rgba(0, 0, 0, 0.12)';

// [[umbra], [penumbra], [ambient]]
const webShadows = [
  [[0, 0, 0], [0, 0, 0], [0, 0, 0]],
  [[2, 1, -1], [1, 1, 0], [1, 3, 0]],
  [[3, 1, -2], [2, 2, 0], [1, 5, 0]],
  [[3, 3, -2], [3, 4, 0], [1, 8, 0]],
  [[2, 4, -1], [4, 5, 0], [1, 10, 0]],
  [[3, 5, -1], [5, 8, 0], [1, 14, 0]],
  [[3, 5, -1], [6, 10, 0], [1, 18, 0]],
  [[4, 5, -2], [7, 10, 1], [2, 16, 1]],
  [[5, 5, -3], [8, 10, 1], [3, 14, 2]],
  [[5, 6, -3], [9, 12, 1], [3, 16, 2]],
  [[6, 6, -3], [10, 14, 1], [4, 18, 3]],
  [[6, 7, -4], [11, 15, 1], [4, 20, 3]],
  [[7, 8, -4], [12, 17, 2], [5, 22, 4]],
  [[7, 8, -4], [13, 19, 2], [5, 24, 4]],
  [[7, 9, -4], [14, 21, 2], [5, 26, 4]],
  [[8, 9, -5], [15, 22, 2], [6, 28, 5]],
  [[8, 10, -5], [16, 24, 2], [6, 30, 5]],
  [[8, 11, -5], [17, 26, 2], [6, 32, 5]],
  [[9, 11, -5], [18, 28, 2], [7, 34, 6]],
  [[9, 12, -6], [19, 29, 2], [7, 36, 6]],
  [[10, 13, -6], [20, 31, 3], [8, 38, 7]],
  [[10, 13, -6], [21, 33, 3], [8, 40, 7]],
  [[10, 14, -6], [22, 35, 3], [8, 42, 7]],
  [[11, 14, -7], [23, 36, 3], [9, 44, 8]],
  [[11, 15, -7], [24, 38, 3], [9, 46, 8]],
];

const getWebShadows = (n: number) => ([
  `0px ${webShadows[n][0][0]}px ${webShadows[n][0][1]}px ${webShadows[n][0][2]}px ${umbraColor}`,
  `0px ${webShadows[n][1][0]}px ${webShadows[n][1][1]}px ${webShadows[n][1][2]}px ${penumbraColor}`,
  `0px ${webShadows[n][2][0]}px ${webShadows[n][2][1]}px ${webShadows[n][2][2]}px ${ambientColor}`,
]).join(', ');

const getNativeShadows = (n: number) => ({
  shadowColor: 'black',
  shadowOpacity: n && 0.23,
  shadowRadius: 0.5 * n,
  shadowOffset: {
    height: 0.92 * n,
    width: 0,
  },
  zIndex: 1,
});

const styles = StyleSheet.create({
  transition: {
    ...Platform.select({
      web: {
        transitionDuration: '0.25s',
        transitionProperty: 'box-shadow',
        transitionTimingFunction: 'cubic-bezier(0.4, 0, 0.2, 1)',
        willChange: 'box-shadow',
      },
    }),
  },
  ...Platform.select({
    web: webShadows.reduce((result, current, index) => ({
      ...result,
      [`shadow--${index}`]: {
        boxShadow: getWebShadows(index),
      },
    }), {}),
    ios: webShadows.reduce((result, current, index) => ({
      ...result,
      [`shadow--${index}`]: getNativeShadows(index),
    }), {}),
  }),
});

export default styles;

==> react-native-web-material-0.5.3.tgz: package/src/Elevation/Elevation.styles.js <==
// @flow
// $FlowFixMe
import { Platform, StyleSheet } from 'react-native';

const umbraColor = 'rgba(0, 0, 0, 0.2)';
const penumbraColor = 'rgba(0, 0, 0, 0.14)';
const ambientColor = 'rgba(0, 0, 0, 0.12)';

// [[umbra], [penumbra], [ambient]]
const webShadows = [
  [[0, 0, 0], [0, 0, 0], [0, 0, 0]],
  [[2, 1, -1], [1, 1, 0], [1, 3, 0]],
  [[3, 1, -2], [2, 2, 0], [1, 5, 0]],
  [[3, 3, -2], [3, 4, 0], [1, 8, 0]],
  [[2, 4, -1], [4, 5, 0], [1, 10, 0]],
  [[3, 5, -1], [5, 8, 0], [1, 14, 0]],
  [[3, 5, -1], [6, 10, 0], [1, 18, 0]],
  [[4, 5, -2], [7, 10, 1], [2, 16, 1]],
  [[5, 5, -3], [8, 10, 1], [3, 14, 2]],
  [[5, 6, -3], [9, 12, 1], [3, 16, 2]],
  [[6, 6, -3], [10, 14, 1], [4, 18, 3]],
  [[6, 7, -4], [11, 15, 1], [4, 20, 3]],
  [[7, 8, -4], [12, 17, 2], [5, 22, 4]],
  [[7, 8, -4], [13, 19, 2], [5, 24, 4]],
  [[7, 9, -4], [14, 21, 2], [5, 26, 4]],
  [[8, 9, -5], [15, 22, 2], [6, 28, 5]],
  [[8, 10, -5], [16, 24, 2], [6, 30, 5]],
  [[8, 11, -5], [17, 26, 2], [6, 32, 5]],
  [[9, 11, -5], [18, 28, 2], [7, 34, 6]],
  [[9, 12, -6], [19, 29, 2], [7, 36, 6]],
  [[10, 13, -6], [20, 31, 3], [8, 38, 7]],
  [[10, 13, -6], [21, 33, 3], [8, 40, 7]],
  [[10, 14, -6], [22, 35, 3], [8, 42, 7]],
  [[11, 14, -7], [23, 36, 3], [9, 44, 8]],
  [[11, 15, -7], [24, 38, 3], [9, 46, 8]],
];

const getWebShadows = (n: number) => ([
  `0px ${webShadows[n][0][0]}px ${webShadows[n][0][1]}px ${webShadows[n][0][2]}px ${umbraColor}`,
  `0px ${webShadows[n][1][0]}px ${webShadows[n][1][1]}px ${webShadows[n][1][2]}px ${penumbraColor}`,
  `0px ${webShadows[n][2][0]}px ${webShadows[n][2][1]}px ${webShadows[n][2][2]}px ${ambientColor}`,
]).join(', ');

const getNativeShadows = (n: number) => (n === 0 ? {} : {
  shadowColor: 'black',
  shadowOpacity: n && 0.23,
  shadowRadius: 0.5 * n,
  shadowOffset: {
    height: 0.92 * n,
    width: 0,
  },
  zIndex: 1,
});

const styles = StyleSheet.create({
  transition: {
    ...Platform.select({
      web: {
        transitionDuration: '0.25s',
        transitionProperty: 'box-shadow',
        transitionTimingFunction: 'cubic-bezier(0.4, 0, 0.2, 1)',
        willChange: 'box-shadow',
      },
    }),
  },
  ...Platform.select({
    web: webShadows.reduce((result, current, index) => ({
      ...result,
      [`shadow--${index}`]: index === 0 ? {} : {
        boxShadow: getWebShadows(index),
      },
    }), {}),
    ios: webShadows.reduce((result, current, index) => ({
      ...result,
      [`shadow--${index}`]: getNativeShadows(index),
    }), {}),
  }),
});

export default styles;
